@@ -1,9 +1,10 @@
 import asyncio
 
 import typer
+from rich import print
 from typing_extensions import Annotated
 
-from platzi import AsyncPlatzi
+from platzi import AsyncPlatzi, Cache
 
 app = typer.Typer(rich_markup_mode="rich")
 
@@ -39,6 +40,24 @@ def download(
             show_default=False,
         ),
     ],
+    quality: Annotated[
+        str,
+        typer.Option(
+            "--quality",
+            "-q",
+            help="The quality of the video to download.",
+            show_default=True,
+        ),
+    ] = False,
+    overwrite: Annotated[
+        bool,
+        typer.Option(
+            "--overwrite",
+            "-w",
+            help="Overwrite files if exist.",
+            show_default=True,
+        ),
+    ] = False,
 ):
     """
     Download a Platzi course from the given URL.
@@ -50,9 +69,21 @@ def download(
         platzi download <url>
 
     Example:
-        platzi download https://platzi.com/cursos/fastapi-2023/
+        platzi download https://platzi.com/cursos/python/
     """
-    asyncio.run(_download(url))
+    asyncio.run(_download(url, quality=quality, overwrite=overwrite))
+
+
+@app.command()
+def clear_cache():
+    """
+    Clear the Platzi CLI cache.
+
+    Usage:
+        platzi clear-cache
+    """
+    Cache.clear()
+    print("[green]Cache cleared successfully 🗑️[/green]")
 
 
 async def _login():
@@ -65,6 +96,6 @@ async def _logout():
         await platzi.logout()
 
 
-async def _download(url: str):
+async def _download(url: str, **kwargs):
     async with AsyncPlatzi() as platzi:
-        await platzi.download(url)
+        await platzi.download(url, **kwargs)
